@@ -49,6 +49,7 @@ def get_utm_zone(longitude):
 def transform_wgs84_to_utm(lon, lat, zone=None):
     # type: (float, float, int) -> (float, float)
     """Return easting, northing, altitude for the given Lon/Lat coordinate.
+
     :param lon:     longitude
     :param lat:     latitude
     :param zone:    UTM zone (if not set it is derived automatically)
@@ -136,7 +137,7 @@ def mapXY2imXY(mapXY, gt):
         if ndim == 1:
             mapXY = mapXY.reshape(1, 2)
         assert mapXY.shape[1] == 2, 'An array in shape [Nx2] is needed. Got shape %s.' % mapXY.shape
-        imXY = np.empty_like(mapXY, dtype=np.float)
+        imXY = np.empty_like(mapXY, dtype=float)
         imXY[:, 0] = (mapXY[:, 0] - gt[0]) / gt[1]
         imXY[:, 1] = (mapXY[:, 1] - gt[3]) / gt[5]
         return imXY if ndim > 1 else imXY.flatten()
@@ -158,7 +159,7 @@ def imXY2mapXY(imXY, gt):
         if imXY.ndim == 1:
             imXY = imXY.reshape(1, 2)
         assert imXY.shape[1] == 2, 'An array in shape [Nx2] is needed. Got shape %s.' % imXY.shape
-        mapXY = np.empty_like(imXY, dtype=np.float)
+        mapXY = np.empty_like(imXY, dtype=float)
         mapXY[:, 0] = gt[0] + imXY[:, 0] * abs(gt[1])
         mapXY[:, 1] = gt[3] - imXY[:, 1] * abs(gt[5])
         return mapXY if ndim > 1 else mapXY.flatten()
